==> auticko-driver-0.3.tar.bz2: auticko-driver-0.3/ui.h <==
/***************************************************************************

        Auticko - ui.h

        copyright (C) 2002 by Josef Kufner <jkufner@seznam.cz>


     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 2 of the License, or
     (at your option) any later version.

***************************************************************************/

#ifndef AUTICKO_UI_H
#define AUTICKO_UI_H

#define BTN_YES		0x0001
#define BTN_NO		0x0002
#define BTN_OK		0x0010
#define BTN_CANCEL	0x0020
#define BTN_RETRY	0x0100

#define	STYLE_INFO	1
#define STYLE_QUESTION	2
#define STYLE_ERROR	3

#define T_ERR		"\1"
#define T_ERR_I		1
#define T_OK		"\2"
#define T_OK_I		2
#define T_DEBUG		"\3"
#define T_DEBUG_I	3


typedef struct {
	int key;
	int joystick;
	
	void (*fn)(int);
	int data;
	
	char *title;
	char *keyname;
} UI_FN;

extern struct pict_val_struct {
	int l_blink;
	int r_blink;
	int light;
	int right;
	int left;
	int up;
	int down;
} pict_val;

int ui_Init(void);
	/* inicializace uzivatelskeho prostredi
	 */

int ui_Clean_Up (void);
	/* Likvidace uzivatelskeho prostredi
	 */

int ui_Refresh(const UI_FN *ui_fn);
	/* Celkove prekresleni obrazovky
	 */

int ui_Update(const UI_FN *ui_fn);
	/* Aktualizace dat na obrazovce
	 */

int ui_User(const UI_FN *ui_fn, int input);
	/* Pece o uzivatele
	 *  - nacteni klavesnice, vesele packy (joystick), ...
	 *  - zavolani zaregistrovane funkce
	 *
	 * blokuje se
	 *
	 * Vraci:
	 *   < -1 ... Chyba
	 *   -1   ... Nic se nedelo
	 *   >= 0 ... index polozky pole, ktere je aktivovano
	 */

int ui_Question(const char *str, const unsigned short btn, const int style);
	/* Otazka uzivateli
	 *  str   ... text otazky
	 *  btn   ... moznosti odpovedi
	 *  style ... styl zobrazeni (otazka, informace, chyba, ...)
	 */

int ui_StrIn(const char *label, char *buf, const int maxlen);
	/* Vyzadani retezce
	 *  label  ... nadpis zadosti
	 *  buf    ... vystup funkce - to, co uziv. zadal
	 *  maxlen ... maximalni delka buf
	 */

void ui_Terminal(char *str, ...);
	/* Prida str do okenka terminalu
	 * chova se jako printf
	 */

void ui_Draw_Picture (void);
	/* Prekresli obrazek auticka
	 */

#endif

==> auticko-driver-0.15.tar.bz2: auticko-driver-0.15/ui.h <==
/***************************************************************************

        Auticko - ui.h

        copyright (C) 2002 by Josef Kufner <jkufner@seznam.cz>


     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 2 of the License, or
     (at your option) any later version.

***************************************************************************/

#ifndef AUTICKO_UI_H
#define AUTICKO_UI_H

#define BTN_YES		0x0001
#define BTN_NO		0x0002
#define BTN_OK		0x0010
#define BTN_CANCEL	0x0020
#define BTN_RETRY	0x0100

#define	STYLE_INFO	1
#define STYLE_QUESTION	2
#define STYLE_ERROR	3

#define JOYSTICK_X	1
#define JOYSTICK_Y	2
#define JOYSTICK_BTN	3

#define T_ERR		"\1"
#define T_ERR_I		1
#define T_OK		"\2"
#define T_OK_I		2
#define T_DEBUG		"\3"
#define T_DEBUG_I	3

typedef struct {
	int key;
	int joystick;
	
	void (*fn)(void);
	
	char *title;
	char *keyname;
} UI_FN;

extern struct pict_val_struct {
	int l_blink;
	int r_blink;
	int light;
	int right;
	int left;
	int up;
	int down;
} pict_val;

int ui_Init(void);
	/* inicializace uzivatelskeho prostredi
	 */

int ui_Clean_Up (void);
	/* Likvidace uzivatelskeho prostredi
	 */

int ui_Refresh(const UI_FN *ui_fn);
	/* Celkove prekresleni obrazovky
	 */

int ui_Update(const UI_FN *ui_fn);
	/* Aktualizace dat na obrazovce
	 */

int ui_User(const UI_FN *ui_fn);
	/* Pece o uzivatele
	 *  - nacteni klavesnice, vesele packy (joystick), ...
	 *  - zavolani zaregistrovane funkce
	 *
	 * blokuje se
	 *
	 * Vraci:
	 *   < -1 ... Chyba
	 *   -1   ... Nic se nedelo
	 *   >= 0 ... index polozky pole, ktere je aktivovano
	 */

int ui_Question(const char *str, const unsigned short btn, const int style);
	/* Otazka uzivateli
	 *  str   ... text otazky
	 *  btn   ... moznosti odpovedi
	 *  style ... styl zobrazeni (otazka, informace, chyba, ...)
	 */

int ui_StrIn(const char *label, char *buf, const int maxlen);
	/* Vyzadani retezce
	 *  label  ... nadpis zadosti
	 *  buf    ... vystup funkce - to, co uziv. zadal
	 *  maxlen ... maximalni delka buf
	 */

long int ui_Get_Joystick (int id);
	/* Nactni hodnoty joystiku
	 *
	 * id ... Co chceme nacist (viz JOYSTICK_* )
	 * 
	 * vraci hodnotu (pokud neni id platne tak 0)
	 * 
	 * u zjistovani tlacitek odbovida pozice bitu cislu tlacitka
	 * napr: 0x0000005, kdyz je prvni a treti tlacitko stisknuto
	 */

void ui_Terminal(char *str, ...);
	/* Prida str do okenka terminalu
	 * chova se jako printf
	 */

void ui_Draw_Picture (void);
	/* Prekresli obrazek auticka
	 */

#endif
